@@ -178,6 +178,24 @@ class ErrorCodes(object):
         CanOnlyAddEvidenceDocumentToDispute = "95703"
         CanOnlyAcceptOpenDispute = "95704"
         CanOnlyFinalizeOpenDispute = "95705"
+        CanOnlyCreateEvidenceWithValidCategory = "95706"
+        EvidenceContentDateInvalid = "95707"
+        EvidenceContentTooLong = "95708"
+        EvidenceContentARNTooLong = "95709"
+        EvidenceContentPhoneTooLong = "95710"
+        EvidenceCategoryTextOnly = "95711"
+        EvidenceCategoryDocumentOnly = "95712"
+        EvidenceCategoryNotForReasonCode = "95713"
+        EvidenceCategoryDuplicate = "95714"
+        EvidenceContentEmailInvalid = "95715"
+
+        DigitalGoodsMissingEvidence = "95720"
+        DigitalGoodsMissingDownloadDate = "95721"
+        NonDisputedPriorTransactionEvidenceMissingARN = "95722"
+        NonDisputedPriorTransactionEvidenceMissingDate = "95723"
+        RecurringTransactionEvidenceMissingDate = "95724"
+        RecurringTransactionEvidenceMissingARN = "95725"
+        ValidEvidenceRequiredToFinalize = "95726"
 
     class DocumentUpload(object):
         KindIsInvalid = "84901"
@@ -341,6 +359,9 @@ class ErrorCodes(object):
         InvalidFundingSourceSelection = "92913"
         CannotUpdatePayPalAccountUsingPaymentMethodNonce = "92914"
 
+        class Options(object):
+            UsBankAccountVerificationMethodIsInvalid = "93121"
+
     class PayPalAccount(object):
         CannotHaveBothAccessTokenAndConsentCode = "82903"
         CannotVaultOneTimeUsePayPalAccount = "82902"
@@ -561,6 +582,8 @@ class ErrorCodes(object):
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
+        UsBankAccountNonceMustBePlaidVerified = "915171"
+        UsBankAccountNotVerified = "915172"
 
         class Options(object):
             SubmitForSettlementIsRequiredForCloning = "91544"
@@ -594,7 +617,8 @@ class ErrorCodes(object):
             DescriptionIsTooLong = "95803"
             DiscountAmountFormatIsInvalid = "95804"
             DiscountAmountIsTooLarge = "95805"
-            DiscountAmountMustBeGreaterThanZero = "95806"
+            DiscountAmountMustBeGreaterThanZero = "95806" # Deprecated as the amount may be zero.
+            DiscountAmountCannotBeNegative = "95806"
             KindIsInvalid = "95807"
             KindIsRequired = "95808"
             NameIsRequired = "95822"
@@ -614,4 +638,16 @@ class ErrorCodes(object):
             UnitOfMeasureIsTooLarge = "95821"
             UnitTaxAmountFormatIsInvalid = "95824"
             UnitTaxAmountIsTooLarge = "95825"
-            UnitTaxAmountMustBeGreaterThanZero = "95826"
+            UnitTaxAmountMustBeGreaterThanZero = "95826" # Deprecated as the amount may be zero.
+            UnitTaxAmountCannotBeNegative = "95826"
+            TaxAmountFormatIsInvalid = "95827"
+            TaxAmountIsTooLarge = "95828"
+            TaxAmountCannotBeNegative = "95829"
+
+    class UsBankAccountVerification(object):
+        NotConfirmable = "96101"
+        MustBeMicroTransfersVerification = "96102"
+        AmountsDoNotMatch = "96103"
+        TooManyConfirmationAttempts = "96104"
+        UnableToConfirmDepositAmounts = "96105"
+        InvalidDepositAmounts = "96106"
